/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataLaunchdarklyTeamMemberConfig extends cdktf.TerraformMetaArguments {
    /**
    * The unique email address associated with the team member.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.25.1/docs/data-sources/team_member#email DataLaunchdarklyTeamMember#email}
    */
    readonly email: string;
    /**
    * role_attributes block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.25.1/docs/data-sources/team_member#role_attributes DataLaunchdarklyTeamMember#role_attributes}
    */
    readonly roleAttributes?: DataLaunchdarklyTeamMemberRoleAttributes[] | cdktf.IResolvable;
}
export interface DataLaunchdarklyTeamMemberRoleAttributes {
    /**
    * The key / name of your role attribute. In the example `$${roleAttribute/testAttribute}`, the key is `testAttribute`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.25.1/docs/data-sources/team_member#key DataLaunchdarklyTeamMember#key}
    */
    readonly key: string;
    /**
    * A list of values for your role attribute. For example, if your policy statement defines the resource `"proj/$${roleAttribute/testAttribute}"`, the values would be the keys of the projects you wanted to assign access to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.25.1/docs/data-sources/team_member#values DataLaunchdarklyTeamMember#values}
    */
    readonly values: string[];
}
export declare function dataLaunchdarklyTeamMemberRoleAttributesToTerraform(struct?: DataLaunchdarklyTeamMemberRoleAttributes | cdktf.IResolvable): any;
export declare function dataLaunchdarklyTeamMemberRoleAttributesToHclTerraform(struct?: DataLaunchdarklyTeamMemberRoleAttributes | cdktf.IResolvable): any;
export declare class DataLaunchdarklyTeamMemberRoleAttributesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataLaunchdarklyTeamMemberRoleAttributes | cdktf.IResolvable | undefined;
    set internalValue(value: DataLaunchdarklyTeamMemberRoleAttributes | cdktf.IResolvable | undefined);
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _values?;
    get values(): string[];
    set values(value: string[]);
    get valuesInput(): string[] | undefined;
}
export declare class DataLaunchdarklyTeamMemberRoleAttributesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataLaunchdarklyTeamMemberRoleAttributes[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataLaunchdarklyTeamMemberRoleAttributesOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.25.1/docs/data-sources/team_member launchdarkly_team_member}
*/
export declare class DataLaunchdarklyTeamMember extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "launchdarkly_team_member";
    /**
    * Generates CDKTF code for importing a DataLaunchdarklyTeamMember resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataLaunchdarklyTeamMember to import
    * @param importFromId The id of the existing DataLaunchdarklyTeamMember that should be imported. Refer to the {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.25.1/docs/data-sources/team_member#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataLaunchdarklyTeamMember to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.25.1/docs/data-sources/team_member launchdarkly_team_member} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataLaunchdarklyTeamMemberConfig
    */
    constructor(scope: Construct, id: string, config: DataLaunchdarklyTeamMemberConfig);
    get customRoles(): string[];
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
    get firstName(): string;
    get id(): string;
    get lastName(): string;
    get role(): string;
    private _roleAttributes;
    get roleAttributes(): DataLaunchdarklyTeamMemberRoleAttributesList;
    putRoleAttributes(value: DataLaunchdarklyTeamMemberRoleAttributes[] | cdktf.IResolvable): void;
    resetRoleAttributes(): void;
    get roleAttributesInput(): cdktf.IResolvable | DataLaunchdarklyTeamMemberRoleAttributes[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
